## 格利pc交接文档

#### 关于更新注意事件

+ 由于缓存问题，每次更新手动需要更新 js 文件的版本号
  - static/js/uitil.js

  ```javascript
  // 第一行 这里的版本号用用于后面动态加载js用的
  var appVersion = "2.5.4";
  ```

  - /theme/mall/default/public

  ```javascript
  // header2.html
  <link rel="stylesheet" href="/themes/mall/default/css/min/${app}.css?v=2.5.4">
  // update.html
  <script src="/static/js/util.js?v=2.5.4"></script>
  <script src="/themes/mall/default/js/min/${app}.js?v=2.5.4"></script>
  ```

+ 更改vue压缩包(这里更新时不改压缩包影响也不是很大，但是建议改了)
> /public/update.html

```javascript
<script src="/static/js/vue/dist/vue.js"></script>
// 修改为
<script src="/static/js/vue/dist/vue.min.js"></script>
```

+ 动态加载 js 和 css
  > 动态插入 script 做加载

```javascript
// wargin 这里必须依赖util.js 因此你必须引用footer2.html或者update.html，再或者你可以手动单独用script标签引用util.js
// loadCssLink是没有回调函数的
// loadJs可以传入回调函数，在动态插入js脚本后执行
<script>
  loadCssLink('/themes/mall/default/css/min/xy_detail.css')
  loadJs('/themes/mall/default/js/min/localfood/xy_detail.js')
</script>
```

#### 关于设置 Vue 的 prototype

> 如果你想和 vuecli 构建单页面一样使用 prototype, 这里你可以在 public/update.html 里面，在<script src="/themes/mall/default/js/min/${app}.js?v=2.5.4"></script>这个标签前面添加 script，如下

```javascript
// ...
<script src="/${app}/jslang.jl"></script>
<script>Vue.prototype.$t = () => console.log(111)</script>
<script src="/themes/mall/default/js/min/${app}.js?v=2.5.4"></script>
```

#### bug

## 关于 jquery.lazyload 和 vue 渲染的问题

> 产生问题的原因：图片加载失败和 lazyload 都会重新设置 img 的 src，导致 vue 绑定的值失效。
> 解决办法：

- 1.如果是单图，那就直接用 jq 或者 vue 在获取数据后直接修改 dom 的 src 值
- 2.如果是列表就不能用上面的方法，当然，用也是可以的，遍历修改。目前我的解决办法是在 static/util.js 的 lazyload 函数直接让某个用 vue 的页面不用懒加载
- 最好的做法(前面两种只是将错就错的做法)

```javascript
// 将下面函数替换static/util.js 的 lazyload 函数, 然后搜索全局data-original, 将所有的img 添加类名lazyload，改动涉及太多(45个文件119处修改)
// 然后后面所有需要懒加载的手动加类名lazyload，vue直接用src="i.img || loading.png"（也可以写在util里面，因为util在vue之后）
function lazyload() {
  $("img").error(function () {
    //当图片加载失败时的操作
    $(this).attr("src", "/themes/mall/default/images/loading.png");
  });
  document.addEventListener(
    "error",
    function (event) {
      var ev = event ? event || window.event : "";
      var elem = ev.target;

      if (elem.tagName.toLowerCase() == "img") {
        // 图片加载失败  --替换为默认
        elem.src = "/themes/mall/default/images/loading.png";
      }
    },
    true
  );
  $("img.lazyload").lazyload({
    placeholder: "",
    effect: "fadeIn",
    event: "scroll",
    threshold: 300,
    skip_invisible: false,
  });
}
```

#### 新开页面使用模板
```javascript
<% include("../public/header2.html"){} %>  // 这个会引用了很多公用的css和一个jq
    <!-- 顶部导航条 -->
    <% include("../public/shortcut_1.html"){} %>
    <!-- 公共头 -->
    <!-- <% include("../public/header_3.html"){} %> -->
	
    <div>内容</div>
	
    <!-- 公共页脚 -->
	// footer2.html和update.html二选一（不用两个都引用）
	// footer2.html插入了update.html
	// 使用关键看你需不需要footer，如果不需要直接用update
    <% include("../public/update.html"){} %>
	<% include("../public/footer2.html"){} %>
	
	// 动态插入js css必须在update.html或者footer2.html之后，引用需要util.js, 如下
	<script>
	loadCssLink('/themes/mall/default/css/min/xy_detail.css')
	loadJs('/themes/mall/default/js/min/localfood/xy_detail.js')
	</script>
    </body>
</html>
```

#### 关于iconfont(已经转让给啸山)
> 新加icon，添加后把iconfont.css丢到对应的文件覆盖(主要@font-face src我的引用，小程序我用的是base64, pc用的是ttf)
+ geli_zs 专属小程序的iconfont
+ geli_pc__old 格利pc用到的iconfont
+ geli 重构pc端用到的iconfont

#### 关于渲染时vue的{{}}的问题
+ 通过延时解决，这个可能会出问题，但基本不会出现，做优惠券时也是复制之前的代码看到的
+ 把vue实例化的dom的css设置`display:none`, 然后再mounted生命周期钩子把dom设置了可见 `$('dom').show()`或者`this.$refs[dom].style.disply = 'block'`

#### 注意
+ 不要使用第三方cdn(你不能保证别人的cdn会不会挂)
+ 尽量少用es6+的新语法，比如async。 因为没经过babel转换，不同浏览器会有兼容问题
+ 不要用axios了(用了也解决不了这座祖传代码)， 直接用util下的__ajax
+ 编译和压缩，引用全部用对应目录下的min/
	- 压缩js  js/js下的文件全部压缩到js/min下面
	- 压缩css css/less下的文件全部压缩到css/min下面


## [关于pc重构说明(目前已暂停)](http://git.gelifood.com/June/gelifood_pc/-/blob/master/README.md)
## [专属小程序](./readme.md)